@@ -1,6 +1,6 @@
 import abc
 from attr import define, field
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Optional
 
 
 @define
@@ -8,6 +8,7 @@ class AbstractLineSegmenter:
     """
     Abstract class for line segmentation backends.
     """
+
     ocr: Any = field()
 
     @abc.abstractproperty
@@ -20,6 +21,7 @@ class AbstractBlockSegmenter:
     """
     Abstract class for block segmentation backends.
     """
+
     ocr: Any = field()
 
     @abc.abstractproperty
@@ -32,9 +34,11 @@ class AbstractTextOCR:
     """
     Abstract class for Text OCR backends.
     """
-    reader: Any = field()
 
-    @abc.abstractproperty
+    reader: Any = field()
+    credentials: str = field()
+
+    @abc.abstractmethod
     def parse(self):
         return NotImplemented
 
@@ -44,12 +48,9 @@ class AbstractTableOCR:
     """
     Abstract class for Table OCR backends.
     """
-    document: Any = field()
 
-    @abc.abstractproperty
-    def metadata(self) -> Dict[str, Any]:
-        return NotImplementedError
+    credentials: Optional[str] = field(default=None)
 
-    @abc.abstractproperty
-    def tables(self) -> List[List]:
+    @abc.abstractmethod
+    def parse(self) -> List[List]:
         return NotImplemented
